/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import org.apache.tools.ant.DynamicElement;

import java.util.HashMap;
import java.util.Map;


/**
 * <p>
 * This class represents all the credentials information for accessing the server. It simply maps property keys to
 * property values.
 * </p>
 *
 * <p>
 * In the build file, this class represents all the child elements under the "credentials" element. The names of the
 * elements represent the property keys, the values of the "value" attributes represent the property values. Here is a
 * sample:
 * <pre>
 * &lt;credentials&gt;
 *   &lt;user_name value="topcoder" /&gt;
 *   &lt;password value="123456" /&gt;
 * &lt;/credentials&gt;
 * </pre>
 * </p>
 *
 * <p>
 * This class is not thread-safe. However the methods will be called one by one by the Ant framework according to the
 * life cycle of ant task. So thread-safety is not an issue here.
 * </p>
 *
 * @author real_vg, TCSDEVELOPER
 * @version 1.0
 */
public class CredentialsElement implements DynamicElement {
    /**
     * <p>
     * Represents the property map to add the credentials properties into. It is a mapping from the property keys
     * (String) to property values (String). It is set in the constructor and the reference is never changed. It is
     * passed to the CredentialProperty through its constructor. It cannot be null.
     * </p>
     */
    private final Map propertyMap;

    /**
     * <p>
     * Creates a new instance of this class.
     * </p>
     */
    public CredentialsElement() {
        propertyMap = new HashMap();
    }

    /**
     * <p>
     * Creates a nested element with the specified name. The nested element must be of type CredentialProperty.
     * </p>
     *
     * @param name the name of the nested element.
     *
     * @return the nested element, must be of type CredentialProperty.
     *
     * @throws IllegalArgumentException if name is null or empty string.
     */
    public Object createDynamicElement(String name) {
        return new CredentialProperty(name, propertyMap);
    }

    /**
     * <p>
     * Returns the property map representing all the credentials information. No copy of the inner map is made.
     * </p>
     *
     * @return the property map representing all the credentials information.
     */
    public Map getPropertyMap() {
        return propertyMap;
    }
}
