/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.io.File;


/**
 * Unit tests for ApplicationServer implementation.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class ApplicationServerTest extends TestCase {
    /**
     * The ApplicationServer instance to test against.
     */
    private ApplicationServer server = null;

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(ApplicationServerTest.class);

        return suite;
    }

    /**
     * Prepares an ApplicationServer instance for testing.
     */
    protected void setUp() {
        server = new SimpleApplicationServer("type");
    }

    /**
     * Tests the constructor with null type. Expects IllegalArgumentException.
     */
    public void testConstructor_NullType() {
        try {
            new SimpleApplicationServer(null);
            fail("Creates ApplicationServer with null type");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Tests the constructor with empty type. Expects IllegalArgumentException.
     */
    public void testConstructor_EmptyType() {
        try {
            new SimpleApplicationServer("");
            fail("Creates ApplicationServer with empty type");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of getWarFile and setWarFile methods with war file specified. Verifies it by getting the war file back
     * after setting it.
     */
    public void testGetSetWarFile_Specified() {
        File warFile = new File("");

        server.setWarFile(warFile);
        assertEquals("Returns an incorrect war file", warFile, server.getWarFile());
    }

    /**
     * Test of getWarFile method with no war file specified. Should return null.
     */
    public void testGetWarFile_Unspecified() {
        assertNull("Returns an incorrect war file", server.getWarFile());
    }

    /**
     * Test of getEarFile and setEarFile methods with ear file specified. Verifies it by getting the ear file back
     * after setting it.
     */
    public void testGetSetEarFile_Specified() {
        File earFile = new File("");

        server.setEarFile(earFile);
        assertEquals("Returns an incorrect ear file", earFile, server.getEarFile());
    }

    /**
     * Test of getEarFile method with no ear file specified. Should return null.
     */
    public void testGetEarFile_Unspecified() {
        assertNull("Returns an incorrect ear file", server.getEarFile());
    }

    /**
     * A simple implementation of the ApplicationServer class for testing.
     */
    private class SimpleApplicationServer extends ApplicationServer {
        /**
         * Creates a new instance of ApplicationServer.
         *
         * @param type the type of the server.
         */
        public SimpleApplicationServer(String type) {
            super(type);
        }

        /**
         * Starts the server. This method should be called before running the tests.
         */
        public void startUp() {
            // empty implementation
        }

        /**
         * Stops the server. This method should be called after running the tests.
         */
        public void shutDown() {
            // empty implementation
        }

        /**
         * Initializes the server with data. This method should be called before running the tests.
         */
        public void initData() {
            // empty implementation
        }

        /**
         * Cleans up the data for the server initialized by the initData() method. This method should be called after
         * running the tests.
         */
        public void cleanUpData() {
            // empty implementation
        }
    }
}
