/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.util.Map;


/**
 * Unit tests for CredentialsElement implementation.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class CredentialsElementTest extends TestCase {
    /**
     * The CredentialsElement instance to test against.
     */
    private CredentialsElement credentials = null;

    /**
     * The name of the credential property.
     */
    private String name = null;

    /**
     * The value of the credential property.
     */
    private String value = null;

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(CredentialsElementTest.class);

        return suite;
    }

    /**
     * Prepares a CredentialsElement instance for testing.
     */
    protected void setUp() {
        name = "name";
        value = "value";
        credentials = new CredentialsElement();
    }

    /**
     * Tests the accessibility of constructor.
     */
    public void testConstructor() {
        new CredentialsElement();
    }

    /**
     * Test of createDynamicElement method with null name. Expects IllegalArgumentException.
     */
    public void testCreateDynamicElement_NullName() {
        try {
            credentials.createDynamicElement(null);
            fail("Creates nested element with null name");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of createDynamicElement method with empty name. Expects IllegalArgumentException.
     */
    public void testCreateDynamicElement_EmptyName() {
        try {
            credentials.createDynamicElement("");
            fail("Creates nested element with empty name");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * Test of createDynamicElement method with non-empty name. Should return an element of type CredentialProperty.
     */
    public void testCreateDynamicElement_NonEmptyName() {
        assertTrue("Returns an incorrect element", credentials.createDynamicElement(name) instanceof CredentialProperty);
    }

    /**
     * Test of getPropertyMap method. First creates a nested element. Sets the value attribute of that element.
     * Verifies if the returned property map contains the credential property represented by that element. This proves
     * that the element name and property map have been passed correctly to create the element.
     */
    public void testGetPropertyMap() {
        CredentialProperty credential = (CredentialProperty) credentials.createDynamicElement(name);

        credential.setValue(value);

        Map propertyMap = credentials.getPropertyMap();

        assertEquals("Returns an incorrect property map", value, propertyMap.get(name));
    }
}
