/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.web;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.apache.cactus.server.HttpServletRequestWrapper;
import org.apache.cactus.server.PageContextWrapper;
import org.apache.cactus.server.ServletConfigWrapper;


/**
 * Unit tests for TCJspTestCase implementation.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class TCJspTestCaseTest extends TestCase {
    /**
     * The TCJspTestCase instance to test against.
     */
    private TCJspTestCase testcase = null;

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(TCJspTestCaseTest.class);

        return suite;
    }

    /**
     * Prepares a TCJspTestCase instance for testing.
     */
    protected void setUp() {
        testcase = new TCJspTestCase();
    }

    /**
     * Tests the constructor with no argument. Verifies if the name of the testcase is null.
     */
    public void testConstructor_NoArg() {
        testcase = new TCJspTestCase();
        assertNull("Fails to set the name", testcase.getName());
    }

    /**
     * Tests the constructor with one argument. Verifies if the name of the testcase is set.
     */
    public void testConstructor_OneArg() {
        String name = "name";

        testcase = new TCJspTestCase(name);
        assertEquals("Fails to set the name", name, testcase.getName());
    }

    /**
     * Test of getConfig method. Verifies if it returns the same reference as the config implicit object.
     */
    public void testGetConfig() {
        testcase.config = new ServletConfigWrapper(null);
        assertSame("Returns an incorrect servlet config", testcase.config, testcase.getConfig());
    }

    /**
     * Test of getRequest method. Verifies if it returns the same reference as the request implicit object.
     */
    public void testGetRequest() {
        testcase.request = new HttpServletRequestWrapper(null, null);
        assertSame("Returns an incorrect HTTP request", testcase.request, testcase.getRequest());
    }

    /**
     * Test of getResponse method. Verifies if it returns the same reference as the response implicit object.
     */
    public void testGetResponse() {
        testcase.response = new SimpleHttpServletResponse();
        assertSame("Returns an incorrect HTTP response", testcase.response, testcase.getResponse());
    }

    /**
     * Test of getSession method. Verifies if it returns the same reference as the session implicit object.
     */
    public void testGetSession() {
        testcase.session = new SimpleHttpSession();
        assertSame("Returns an incorrect HTTP session", testcase.session, testcase.getSession());
    }

    /**
     * Test of getOut method. Verifies if it returns the same reference as the out implicit object.
     */
    public void testGetOut() {
        testcase.out = new SimpleJspWriter();
        assertSame("Returns an incorrect JSP writer", testcase.out, testcase.getOut());
    }

    /**
     * Test of getPageContext method. Verifies if it returns the same reference as the pageContext implicit object.
     */
    public void testGetPageContext() {
        testcase.pageContext = new PageContextWrapper(null, null);
        assertSame("Returns an incorrect JSP page context", testcase.pageContext, testcase.getPageContext());
    }
}
